@@ -36,12 +36,14 @@ from places_geocode.app.models import density_models, common_models, reverse_mod
 
 # cython modules import
 from ctypes import *
-from places_geocode.app.CythonOperations import spreadsheet_c, \
-    reverse_spreadsheet, \
-    TFIDF_max, \
-    null_parameters, \
-    certainty_search, \
-    radius_arr, TFIDF_max_elastic
+spreadsheet_c = cdll.LoadLibrary("places_geocode/app/CythonOperations/spreadsheet_c.cpython-38-darwin.so")
+reverse_spreadsheet = cdll.LoadLibrary("places_geocode/app/CythonOperations/reverse_spreadsheet.cpython-38-darwin.so")
+TFIDF_max = cdll.LoadLibrary("places_geocode/app/CythonOperations/TFIDF_max.cpython-38-darwin.so")
+null_parameters = cdll.LoadLibrary("places_geocode/app/CythonOperations/null_parameters.cpython-38-darwin.so")
+certainty_search = cdll.LoadLibrary("places_geocode/app/CythonOperations/certainty_search.cpython-38-darwin.so")
+radius_arr = cdll.LoadLibrary("places_geocode/app/CythonOperations/radius_arr.cpython-38-darwin.so")
+TFIDF_max_elastic = cdll.LoadLibrary("places_geocode/app/CythonOperations/TFIDF_max_elastic.cpython-38-darwin.so")
+
 
 # ----------------------DataClasses Here---------------------
 
